<?php
namespace ElementorFastMediaGallery;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_scripts() {
		
		// Load WP jQuery if not included
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-masonry');
		
		
		// Load main js script
		wp_enqueue_script( 'elementor-fast-media-gallery-frontend', plugins_url( '/assets/js/fast-gallery.js', __FILE__ ), [ 'jquery' ], false, true );
		
		// Main
		wp_register_style( 'fastmediagallery-vc-main-style', plugins_url( '/assets/css/style.css', __FILE__ ) );
		wp_register_style( 'fonts-vc',  plugins_url( 'assets/css/fonts.css', __FILE__ )); 
		wp_register_style( 'custom-responsive-vc',  plugins_url( 'assets/css/custom_responsive.css', __FILE__ )); 
		wp_enqueue_style( 'fastmediagallery-vc-main-style' );
				
		// LIGHT GALLERY
		wp_register_style( 'lightgallery',  plugins_url( 'assets/css/lightGallery.css', __FILE__ ) );
		wp_register_script( 'lightgallery',  plugins_url( 'assets/js/vendor/lightGallery.min.js' , __FILE__ ), [ 'jquery' ], false, true );		
		wp_register_script( 'lightgallery-vimeo', plugins_url( 'assets/js/vendor/froogaloop2.min.js' , __FILE__ ), [ 'jquery' ], false, true );
				
		// ANIMATE
		wp_register_style( 'animations',  plugins_url( 'assets/css/animations.min.css', __FILE__ ) );
		wp_register_script( 'appear',  plugins_url( 'assets/js/vendor/appear.min.js' , __FILE__ ), [ 'jquery' ], false, true );	
		wp_register_script( 'animate',  plugins_url( 'assets/js/vendor/animations.min.js' , __FILE__ ), [ 'jquery' ], false, true );		
		
		// LAZY LOAD EFFECT
		wp_register_script( 'lazyload',  plugins_url( 'assets/js/vendor/jquery.lazyload.js' , __FILE__ ), [ 'jquery' ], false, true );				
		wp_register_script( 'imagesLoaded',  plugins_url( 'assets/js/vendor/imagesLoaded.js' , __FILE__ ), [ 'jquery' ], false, true );		
		if(\Elementor\Plugin::$instance->preview->is_preview_mode()) {
			wp_enqueue_style( 'fonts-vc' );
			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery' );
			wp_enqueue_script( 'lightgallery-vimeo' );
			wp_enqueue_style( 'animations' );
			wp_enqueue_script( 'appear' );			
			wp_enqueue_script( 'animate' );			
			wp_enqueue_script( 'lazyload' );			
			wp_enqueue_script( 'imagesLoaded' );	
		}			
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.0.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/FastMediaGallery/fast-media-gallery.php' );
		require_once( __DIR__ . '/widgets/widgets-help-functions.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fast_Media_Gallery() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
