<?php
/*************************************************** 
#### Function: fastmediagallery_elementor_enqueue_css_and_javascript() ####
#### Since: version 1.0 ############################
***************************************************/			

function fastmediagallery_elementor_enqueue_css_and_javascript($type,$layout,$responsive_type,$lazyload,$active_custom_responsive,$fg_animate) {
	
		// LOAD GENERAL CSS AND JAVASCRIPT
		wp_enqueue_script('elementor-fast-media-gallery-frontend');
		wp_enqueue_style('fonts-vc');

		// CUSTOM RESPONSIVE: LOAD CSS
		if($active_custom_responsive == 'active_custom_responsive') {	
			wp_enqueue_style( 'custom-responsive-vc' );
		}

		// MASONRY: LOAD JAVASCRIPT 
		if($layout == 'fmg-masonry') {
			wp_enqueue_script('jquery-masonry');
		}
		
		// LIGHTGALLERY: LOAD CSS AND JAVASCRIPT
		if($type == 'lightgallery') {
			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery');					
		}

		if($fg_animate == 'on') {
			wp_enqueue_style( 'animations' );
			wp_enqueue_script( 'appear');
			wp_enqueue_script( 'animate');				
		}

		if($lazyload == 'on') {
			wp_enqueue_script( 'lazyload');
			wp_enqueue_script( 'imagesLoaded');	
		}

}

/*************************************************** 
#### Function: fastmediagallery_elementor_hex2rgb() #######
#### Since: version 1.0 ############################
***************************************************/

function fastmediagallery_elementor_hex2rgb($hex) {

   $hex = str_replace("#", "", $hex);

if(strlen($hex) == 3) {
		$r = hexdec(substr($hex,0,1).substr($hex,0,1));
		$g = hexdec(substr($hex,1,1).substr($hex,1,1));
		$b = hexdec(substr($hex,2,1).substr($hex,2,1));
	} else {
		$r = hexdec(substr($hex,0,2));
		$g = hexdec(substr($hex,2,2));
		$b = hexdec(substr($hex,4,2));
	}
	$rgb = array($r, $g, $b);
	return $rgb;
}

/*************************************************** 
#### Function: fastmediagallery_elementor_pagination() ################
#### Since: version 1.0 ############################
***************************************************/

function fastmediagallery_elementor_pagination($num_page_for_pagination,$pagination) {
	$output = '<ul class="fg_pagination">';
	for($i=1; $i <= $num_page_for_pagination; $i++) {
		
		if($i == $pagination) {
			$output .= '<li class="fg_current">'.$i.'</li>'; // CURRENT PAGE
		} else {
			$output .= '<li><a href="'.get_post_permalink().'&fmg_page='.$i.'">'.$i.'</a></li>'; // OTHER PAGE
		}
	}
	$output .= '</ul>';
	return $output;
}





/*************************************************** 
#### Function: fastmediagallery_elementor_style() #########################
#### Since: version 1.0 ############################
***************************************************/

function fastmediagallery_elementor_style($selector,
				   $main_color,
				   $main_color_opacity,
				   $secondary_color,
				   $spacing_active,
				   $spacing,
				   $name_show,
				   $gallery_name_font_size,
				   $gallery_name_font_color,
				   $gallery_name_text_align,
				   $pagination_active,
				   $pagination_style,
				   $image_width) {
					   
				// CHECK MAIN COLOR
				$rgb_main_color = fastmediagallery_elementor_hex2rgb($main_color);
				$rgba_main_color = "rgba( ".$rgb_main_color[0]." , ".$rgb_main_color[1]." , ".$rgb_main_color[2]." , ".$main_color_opacity.")";	
				$rgb_secondary_color = fastmediagallery_elementor_hex2rgb($secondary_color);
				$rgba_secondary_color = "rgba( ".$rgb_secondary_color[0]." , ".$rgb_secondary_color[1]." , ".$rgb_secondary_color[2]." , 0.3)";	
				// END MAIN COLOR	
			
				$output = "
				<style type='text/css'>
					#{$selector} {
					margin: auto;
					}
					#{$selector} .fg-gallery-item {
					margin-top: 10px;
					text-align: center;
					}
					#{$selector} .fg-gallery-caption {
					margin-left: 0;
					}
					#{$selector}.fastgallery .fg-gallery-caption, 
					#{$selector}.fastgallery .fg-gallery-caption:hover {
						background-color:".$rgba_main_color.";
					}
					#{$selector}.fastgallery.gallery .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.gallery .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$main_color.";
					}
					#{$selector}.fastgallery.fg_style1 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					#{$selector}.fastgallery.gallery.fg_style2 .fastgallery-gallery-icon .fg_zoom a {
						background:".$rgba_secondary_color.";
					}
					#{$selector}.fastgallery.fg_style2 .fg-gallery-caption {
						color:".$secondary_color.";	
					}			
					#{$selector}.fastgallery.gallery.fg_style3 .fg_zoom, #{$selector}.fastgallery.gallery.fg_style3 .fg_zoom:hover {
						background:".$rgba_main_color.";
					}
					#{$selector}.fastgallery.fg_style3 .fg-gallery-caption {
						color:".$secondary_color.";	
					}				
					#{$selector}.fastgallery.fg_style4 .fg-gallery-caption,			
					#{$selector}.fastgallery.gallery.fg_style4 .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.gallery.fg_style4 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
					}
					#{$selector}.fastgallery.gallery.fg_style4 .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.gallery.fg_style4 .fastgallery-gallery-icon .fg_zoom a:hover	{
						background:".$rgba_main_color.";
					}			
					#{$selector}.fastgallery.gallery.fg_style5 .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.gallery.fg_style5 .fastgallery-gallery-icon .fg_zoom a:hover	{
						color:".$secondary_color.";
						background-color:".$rgba_main_color.";
					}					
					#{$selector}.fastgallery.gallery.fg_style6 .fastgallery-gallery-icon .fg_zoom a,
					#{$selector}.fastgallery.gallery.fg_style6 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
						background:".$rgba_main_color.";				
					}
				
					#{$selector}.fastgallery.fg_style6 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					#{$selector}.fastgallery.gallery.fg_style7 .fastgallery-gallery-icon .fg_zoom a,
					#{$selector}.fastgallery.gallery.fg_style7 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
						background:".$rgba_main_color.";				
					}		
					#{$selector}.fastgallery.fg_style7 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					
					#{$selector}.fastgallery.gallery.fg_style8 .fastgallery-gallery-icon .fg_zoom a,
					#{$selector}.fastgallery.gallery.fg_style8 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
						background:".$rgba_main_color.";				
					}
				
					#{$selector}.fastgallery.fg_style8 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					
					#{$selector}.fastgallery.gallery.fg_style9 .fastgallery-gallery-icon .fg_zoom a,
					#{$selector}.fastgallery.gallery.fg_style9 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
						background:".$rgba_main_color.";				
					}		
					#{$selector}.fastgallery.fg_style9 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					
					#{$selector}.fastgallery.gallery.fg_style10 .fastgallery-gallery-icon .fg_zoom a,
					#{$selector}.fastgallery.gallery.fg_style10 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$secondary_color.";
						background:".$rgba_main_color.";				
					}		
					#{$selector}.fastgallery.fg_style10 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					#{$selector}.fastgallery.fg_style11 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					#{$selector}.fastgallery.fg_style11 .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.fg_style11 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$main_color.";
						background:".$rgba_secondary_color.";
					}
					#{$selector}.fastgallery.fg_style12 .fg-gallery-caption {
						color:".$secondary_color.";	
					}
					#{$selector}.fastgallery.fg_style12 .fastgallery-gallery-icon .fg_zoom a, 
					#{$selector}.fastgallery.fg_style12 .fastgallery-gallery-icon .fg_zoom a:hover {
						color:".$main_color.";
						background:".$rgba_secondary_color.";
					}";


				if($spacing_active == 'on') {
					$output .= "
						.fastgallery.gallery {
							width:100%;
							width: -webkit-calc(100% + ".$spacing."px);
							width: calc(100% + ".$spacing."px);
							/*margin-left:".$spacing."px;*/
						}
						.fastgallery .fg-gallery-item {
							margin-right:".$spacing."px!important;
							margin-bottom:".$spacing."px!important;
						}
						.fastgallery.gallery-columns-2 .fg-gallery-item {
							max-width: 48%;
							max-width: -webkit-calc(50% - ".$spacing."px);
							max-width:         calc(50% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-3 .fg-gallery-item {
							max-width: 32%;
							max-width: -webkit-calc(33.3% - ".$spacing."px);
							max-width:         calc(33.3% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-4 .fg-gallery-item {
							max-width: 23%;
							max-width: -webkit-calc(25% - ".$spacing."px);
							max-width:         calc(25% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-5 .fg-gallery-item {
							max-width: 19%;
							max-width: -webkit-calc(20% - ".$spacing."px);
							max-width:         calc(20% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-6 .fg-gallery-item {
							max-width: 15%;
							max-width: -webkit-calc(16.7% - ".$spacing."px);
							max-width:         calc(16.7% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-7 .fg-gallery-item {
							max-width: 13%;
							max-width: -webkit-calc(14.28% - ".$spacing."px);
							max-width:         calc(14.28% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-8 .fg-gallery-item {
							max-width: 11%;
							max-width: -webkit-calc(12.5% - ".$spacing."px);
							max-width:         calc(12.5% - ".$spacing."px);
						}
						
						.fastgallery.gallery-columns-9 .fg-gallery-item {
							max-width: 9%;
							max-width: -webkit-calc(11.1% - ".$spacing."px);
							max-width:         calc(11.1% - ".$spacing."px);
						}
					";
				}

				if($name_show == 'true') {
					$output .= ".fg_gallery_title-{$selector}.fg_gallery_name {
							font-size:".$gallery_name_font_size."px;
							color:".$gallery_name_font_color.";
							text-align:".$gallery_name_text_align.";
					}";
				}

				if($pagination_active == 'on') {
					$output .= "
						#{$selector}.fastgallery.fg_pagination_style1 ul.fg_pagination li a {
							background:".$rgba_main_color.";
							color:".$secondary_color.";
						}
						#{$selector}.fastgallery.fg_pagination_style1 ul.fg_pagination li a:hover {
							background:".$secondary_color.";
							color:".$rgba_main_color.";
						}
						#{$selector}.fastgallery.fg_pagination_style1 ul.fg_pagination li.fg_current {
							background:".$secondary_color.";
							color:".$rgba_main_color.";
						}
						#{$selector}.fastgallery.fg_pagination_style2 ul.fg_pagination li a {
							color:".$secondary_color.";
						}
						#{$selector}.fastgallery.fg_pagination_style2 ul.fg_pagination li a:hover {
							color:".$rgba_main_color.";
						}
						#{$selector}.fastgallery.fg_pagination_style2 ul.fg_pagination li.fg_current {
							color:".$rgba_main_color.";
						}																		
					";
				}

				if($image_width == 'small') {
					$output .= "#{$selector}.fastgallery.gallery span {
										font-size:20px!important;
					}
					#{$selector}.fastgallery.gallery .fg-zoom-icon {
										margin-left:-10px!important;
										margin-top:-40px;
					}
					#{$selector}.fastgallery.gallery.fg_style2 .fg-zoom-icon,
					#{$selector}.fastgallery.gallery.fg_style5 .fg-zoom-icon  {
										margin-top:-10px;
					}		
					#{$selector}.fastgallery.gallery .no-caption .fg-zoom-icon {
										margin-top:-10px!important;
					}
					#{$selector}.fastgallery.fg_style7 .fg-gallery-caption,
					#{$selector}.fastgallery.fg_style8 .fg-gallery-caption {
										top:55%;
					}
					";
				}
				
				if($image_width == 'medium') {
					$output .= "#{$selector}.fastgallery.gallery span {
										font-size:30px!important;
					}
					#{$selector}.fastgallery.gallery .fg-zoom-icon {
										margin-left:-15px!important;
										margin-top:-40px;
					}
					#{$selector}.fastgallery.gallery.fg_style2 .fg-zoom-icon,
					#{$selector}.fastgallery.gallery.fg_style5 .fg-zoom-icon  {
										margin-top:-15px;
					}		
					#{$selector}.fastgallery.gallery .no-caption .fg-zoom-icon {
										margin-top:-15px!important;
					}
					#{$selector}.fastgallery.fg_style7 .fg-gallery-caption,
					#{$selector}.fastgallery.fg_style8 .fg-gallery-caption {
										top:55%;
					}
					";
				}
		
				if($image_width == 'large') {
					$output .= "#{$selector}.fastgallery.gallery span {
										font-size:50px!important;
					}
					#{$selector}.fastgallery .fg-zoom-icon {
										margin-left:-25px!important;
										margin-top:-50px;
					}
					#{$selector}.fastgallery.fg_style1 .fg-zoom-icon,
					#{$selector}.fastgallery.fg_style2 .fg-zoom-icon,
					#{$selector}.fastgallery.fg_style5 .fg-zoom-icon {
										margin-top:-25px;
					}		
					#{$selector}.fastgallery .no-caption .fg-zoom-icon {
										margin-top:-25px!important;
					}
					#{$selector}.fastgallery.fg_style7 .fg-gallery-caption,
					#{$selector}.fastgallery.fg_style8 .fg-gallery-caption {
										top:55%;
					}
					";
				}						
					
			$output .= '</style>';				
	return $output;					
}

?>